pub enum ExportError {
Pdf(PdfError),
Render(RenderError),
}Expand description
A failure to export a figure as a PDF.
Variants
Pdf(PdfError)
The PDF could not be written.
Render(RenderError)
The figure has content that the raster policy rasterises, and the renderer could not be created or could not draw it.